==> ui-0.2.43.tgz: package/lib/cjs/TextField/Textarea/Textarea.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _indexOf = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/index-of"));
var _getOwnPropertySymbols = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-symbols"));
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = _interopRequireDefault(require("react"));
var Styled = _interopRequireWildcard(require("./Textarea.styled"));
var _CharLimit = require("../CharLimit");
var _Asterisk = require("../../Asterisk");
var _HelperText = require("../../HelperText");
function _getRequireWildcardCache(nodeInterop) { if (typeof _WeakMap !== "function") return null; var cacheBabelInterop = new _WeakMap(); var cacheNodeInterop = new _WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? _Object$getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { _Object$defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && (0, _indexOf.default)(e).call(e, p) < 0) t[p] = s[p];
  if (s != null && typeof _getOwnPropertySymbols.default === "function") for (var i = 0, p = (0, _getOwnPropertySymbols.default)(s); i < p.length; i++) {
    if ((0, _indexOf.default)(e).call(e, p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};
const Textarea = /*#__PURE__*/_react.default.forwardRef((_a, ref) => {
  var {
      width = '100%',
      label = '',
      description = '',
      placeholder = '',
      helperText = '',
      errorText = '',
      charLimit = 0,
      mustInput = false,
      hasScrollBar = true,
      isError = false,
      defaultValue = '',
      disabled = false,
      onBlur,
      onChange,
      onFocus,
      applyMaxLength = false
    } = _a,
    rest = __rest(_a, ["width", "label", "description", "placeholder", "helperText", "errorText", "charLimit", "mustInput", "hasScrollBar", "isError", "defaultValue", "disabled", "onBlur", "onChange", "onFocus", "applyMaxLength"]);
  const [, setFocus] = _react.default.useState(false);
  const [inputValue, setInputValue] = _react.default.useState(defaultValue);
  const length = inputValue.length || 0;
  const hasError = isError || !!(charLimit && length > charLimit);
  const hasFooterText = !!helperText || hasError && !!errorText;
  if (applyMaxLength) rest = (0, _assign.default)((0, _assign.default)({}, rest), {
    maxLength: charLimit
  });
  const handleChange = event => {
    setInputValue(event.target.value);
    if (!disabled && typeof onChange === 'function') onChange(event);
  };
  const handleFocus = event => {
    if (!disabled) {
      if (typeof onFocus === 'function') onFocus(event);
      setFocus(true);
    }
  };
  const handleBlur = event => {
    if (!disabled) {
      if (typeof onBlur === 'function') onBlur(event);
      setFocus(false);
    }
  };
  return (0, _jsxRuntime.jsxs)(Styled.DSTextareaWrapper, (0, _assign.default)({
    "$width": width
  }, {
    children: [(label || charLimit || description) && (0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
      children: [(0, _jsxRuntime.jsxs)(Styled.LabelWrapper, (0, _assign.default)({
        "$noLabel": !label
      }, {
        children: [label && (0, _jsxRuntime.jsxs)(Styled.Label, {
          children: [label, mustInput && (0, _jsxRuntime.jsx)(_Asterisk.Asterisk, {})]
        }), charLimit !== 0 && (0, _jsxRuntime.jsx)(_CharLimit.CharLimit, {
          noLabel: !label,
          length: length,
          charLimit: charLimit
        })]
      })), description && (0, _jsxRuntime.jsx)(Styled.Description, {
        children: description
      })]
    }), (0, _jsxRuntime.jsx)(Styled.TextareaBorder, (0, _assign.default)({
      "$isError": hasError,
      "$isExistsValue": !!inputValue,
      "$disabled": disabled
    }, {
      children: (0, _jsxRuntime.jsx)(Styled.Textarea, (0, _assign.default)({
        ref: ref,
        value: inputValue,
        placeholder: placeholder,
        "$isError": hasError,
        "$hasScrollBar": hasScrollBar,
        "$disabled": disabled,
        readOnly: disabled,
        onChange: handleChange,
        onFocus: handleFocus,
        onBlur: handleBlur
      }, rest))
    })), hasFooterText && (0, _jsxRuntime.jsx)(_HelperText.HelperText, (0, _assign.default)({
      color: hasError ? 'error' : 'gray',
      style: {
        marginLeft: '12px'
      }
    }, {
      children: hasError ? errorText : helperText
    }))]
  }));
});
var _default = Textarea;
exports.default = _default;

==> ui-0.2.52.tgz: package/lib/cjs/TextField/Textarea/Textarea.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _indexOf = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/index-of"));
var _getOwnPropertySymbols = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-symbols"));
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = _interopRequireDefault(require("react"));
var Styled = _interopRequireWildcard(require("./Textarea.styled"));
var _CharLimit = require("../CharLimit");
var _Asterisk = require("../../Asterisk");
var _HelperText = require("../../HelperText");
function _getRequireWildcardCache(e) { if ("function" != typeof _WeakMap) return null; var r = new _WeakMap(), t = new _WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? _Object$getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? _Object$defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && (0, _indexOf.default)(e).call(e, p) < 0) t[p] = s[p];
  if (s != null && typeof _getOwnPropertySymbols.default === "function") for (var i = 0, p = (0, _getOwnPropertySymbols.default)(s); i < p.length; i++) {
    if ((0, _indexOf.default)(e).call(e, p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};
const Textarea = /*#__PURE__*/_react.default.forwardRef((_a, ref) => {
  var {
      width = '100%',
      label = '',
      description = '',
      placeholder = '',
      helperText = '',
      errorText = '',
      charLimit = 0,
      mustInput = false,
      hasScrollBar = true,
      isError = false,
      defaultValue = '',
      disabled = false,
      onBlur,
      onChange,
      onFocus,
      applyMaxLength = false
    } = _a,
    rest = __rest(_a, ["width", "label", "description", "placeholder", "helperText", "errorText", "charLimit", "mustInput", "hasScrollBar", "isError", "defaultValue", "disabled", "onBlur", "onChange", "onFocus", "applyMaxLength"]);
  const [, setFocus] = _react.default.useState(false);
  const [inputValue, setInputValue] = _react.default.useState(defaultValue);
  const length = inputValue.length || 0;
  const hasError = isError || !!(charLimit && length > charLimit);
  const hasFooterText = !!helperText || hasError && !!errorText;
  if (applyMaxLength) rest = (0, _assign.default)((0, _assign.default)({}, rest), {
    maxLength: charLimit
  });
  const handleChange = event => {
    setInputValue(event.target.value);
    if (!disabled && typeof onChange === 'function') onChange(event);
  };
  const handleFocus = event => {
    if (!disabled) {
      if (typeof onFocus === 'function') onFocus(event);
      setFocus(true);
    }
  };
  const handleBlur = event => {
    if (!disabled) {
      if (typeof onBlur === 'function') onBlur(event);
      setFocus(false);
    }
  };
  return (0, _jsxRuntime.jsxs)(Styled.DSTextareaWrapper, (0, _assign.default)({
    "$width": width
  }, {
    children: [(label || charLimit || description) && (0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
      children: [(0, _jsxRuntime.jsxs)(Styled.LabelWrapper, (0, _assign.default)({
        "$noLabel": !label
      }, {
        children: [label && (0, _jsxRuntime.jsxs)(Styled.Label, {
          children: [label, mustInput && (0, _jsxRuntime.jsx)(_Asterisk.Asterisk, {})]
        }), charLimit !== 0 && (0, _jsxRuntime.jsx)(_CharLimit.CharLimit, {
          noLabel: !label,
          length: length,
          charLimit: charLimit
        })]
      })), description && (0, _jsxRuntime.jsx)(Styled.Description, {
        children: description
      })]
    }), (0, _jsxRuntime.jsx)(Styled.TextareaBorder, (0, _assign.default)({
      "$isError": hasError,
      "$isExistsValue": !!inputValue,
      "$disabled": disabled
    }, {
      children: (0, _jsxRuntime.jsx)(Styled.Textarea, (0, _assign.default)({
        ref: ref,
        value: inputValue,
        placeholder: placeholder,
        "$isError": hasError,
        "$hasScrollBar": hasScrollBar,
        "$disabled": disabled,
        readOnly: disabled,
        onChange: handleChange,
        onFocus: handleFocus,
        onBlur: handleBlur
      }, rest))
    })), hasFooterText && (0, _jsxRuntime.jsx)(_HelperText.HelperText, (0, _assign.default)({
      color: hasError ? 'error' : 'gray',
      style: {
        marginLeft: '12px'
      }
    }, {
      children: hasError ? errorText : helperText
    }))]
  }));
});
var _default = exports.default = Textarea;
